Subpixel

Enum Subpixel 

pub enum Subpixel {
    Unknown,
    None,
    HorizontalRgb,
    HorizontalBgr,
    VerticalRgb,
    VerticalBgr,
}
Subpixel geometry information

This enumeration describes how the physical pixels on an output are laid out.

Variants



Unknown

Unknown subpixel geometry



None

No subpixel geometry



HorizontalRgb

Subpixels are arranged horizontally starting with red, then green, last blue



HorizontalBgr

Subpixels are arranged horizontally starting with blue, then green, last red



VerticalRgb

Subpixels are arranged vertically starting with red, then green, last blue



VerticalBgr

Subpixels are arranged vertically starting with blue, then green, last red